nanoreactor_driver.py Command Help

Command: $SCHRODINGER/run nanoreactor_gui_dir/nanoreactor_driver.py

usage: $SCHRODINGER/run nanoreactor_gui_dir/nanoreactor_driver.py
       [-h] [-charge CHARGE] [-spins UNPAIRED_ELECTRONS]
       [-final_spins UNPAIRED_ELECTRONS] [-solvent SOLVENT]
       [-md_time PICOSECONDS] [-meta_time PICOSECONDS] [-rmsd_save RMSD_SAVE]
       [-dump FEMTOSECONDS] [-autoscale AUTOSCALE] [-kpush_scale SCALE]
       [-alpha_scale SCALE] [-temp KELVIN] [-react_ident] [-TPP TPP]
       [-bin_time] [-bin_energy] [-no_exhaust] [-trj] [-ts_search]
       [-autots_keywords KEYWORD=VALUE KEYWORD=VALUE ...]
       [-autots_jag_keywords KEYWORD=VALUE KEYWORD=VALUE ...]
       [-HOST <hostname>] [-D] [-JOBNAME JOBNAME] [-taper KCAL/MOL]
       [-reps REPLICATES] [-refine] [-refined_taper KCAL/MOL]
       [-keywords KEYWORD=VALUE KEYWORD=VALUE ...]
       input_file

Base module for the nanoreactor drivers Copyright Schrodinger, LLC. All rights
reserved.

positional arguments:
  input_file            Input file

options:
  -h, -help             Show this help message and exit.
  -charge CHARGE        Overall charge on the system (default: 0)
  -spins UNPAIRED_ELECTRONS
                        Number of unpaired electrons in the initial system
                        (default: 0)
  -final_spins UNPAIRED_ELECTRONS
                        Number of unpaired electrons in the final system. If
                        not given, the -spins value will be used (default:
                        None)
  -solvent SOLVENT      Solvent for the Poisson-Boltzmann solvent model. Must
                        be one of none,acetone,acetonitrile,aniline,benzaldehy
                        de,benzene,ch2cl2,chcl3,cs2,dioxane,dmf,dmso,ether,eth
                        ylacetate,furane,hexadecane,hexane,methanol,nitrometha
                        ne,octanol,woctanol,phenol,toluene,thf,water.
                        (default: none)
  -md_time PICOSECONDS  Picoseconds to run the relaxation MD (default: 10)
  -meta_time PICOSECONDS
                        Picoseconds to run the Metadynamics (default: 500)
  -rmsd_save RMSD_SAVE  The number of reference structures associated with the
                        pushing (k > 0) or pulling (k < 0) strength. Default
                        is calculated by multiplying metadynamics simulation
                        time in fs with integration interval time step.
                        (default: None)
  -dump FEMTOSECONDS    Interval in femtoseconds for trajectory printout
                        during MD and Metadynamics simulations. (default:
                        None)
  -autoscale AUTOSCALE  Prefactor to multiply the automatically determined
                        sphere radius. Radius of the repulsive potential
                        cavity is used to confine the system. Used to avoid
                        spontaneous dissociation of multimolecular systems.
                        (default: 1.0)
  -kpush_scale SCALE    Scale factor for the biasing potential strength.
                        Higher values result in more reactions, but too high
                        can result in non-physical structures. Final kpush =
                        SCALE * 0.02 * number of atoms. (default: 1.0)
  -alpha_scale SCALE    Scale factor for the biasing potential width. A high
                        alpha results in a narrow biasing potential, meaning
                        that the system can escape the bias by smaller changes
                        to the structure. Final alpha = SCALE * 0.7. (default:
                        1.0)
  -temp KELVIN          Set the thermostat temperature for both molecular
                        dynamics and metadynamics run. (default: 600.15)
  -react_ident          Perform elementary reaction network calculation. MD
                        and MTD trajectories are merged and filtered based on
                        identical SMILES representations, (first encountered
                        structure for each SMILES is considered) while
                        preserving their full trajectory histories. Each
                        filtered trajectory is then subjected to sequential
                        xTB minimizations, progressing frame by frame until a
                        structure with a SMILES distinct from that of the
                        reactant is identified. See also flags -bin_time,
                        -bin_energy, and -no_exhaust. (default: False)
  -TPP TPP              The TPP flag is no longer supported. Use -HOST
                        hostname:X to indicate that X processors should be
                        used for the workflow. TPP will be figured
                        automatically. (default: 1)
  -bin_time             Bin structures from unoptimized trajectories by
                        SMILES. The structures in each bin are ordered by
                        increasing simulation time. Consider each structure in
                        each bin in order and identify the product as the
                        first structure for which the SMILES doesn't change
                        when xTB optimized. Structures with reactant SMILES
                        are discarded. (default: False)
  -bin_energy           Bin structures from unoptimized trajectories by
                        SMILES. The structures in each bin are ordered by
                        increasing unoptimized xTB energy from MD and MTD
                        simulation. Consider each structure in each bin in
                        order and identify the product as the first structure
                        for which the SMILES doesn't change when xTB
                        optimized. Structures with reactant SMILES are
                        discarded. (default: False)
  -no_exhaust           Pass this flag along with -bin_time or -bin_energy.
                        Only the structure at the top from each bin are
                        processed. i.e. structure with lowest xTB energy for
                        each unique SMILES in the order of appearance for
                        -bin_energy and first structure based on order of
                        increasing simulation time for -bin_time. (default:
                        False)
  -trj                  If specified, write trajectory files from the MD and
                        Metadynamics xTB calculations and return the per-
                        replicate scratch directories (replicate_<n>/) to the
                        job launch directory for inspection. By default these
                        directories are removed after their contents have been
                        consumed. (default: False)
  -ts_search            If specified, perform transition state search on the
                        identified products from the ERN simulation. (default:
                        False)
  -autots_keywords KEYWORD=VALUE KEYWORD=VALUE ...
                        If performing a transition state search for an ERN
                        simulation using -ts_search then specify extra AutoTS
                        keywords using this flag. The reactant, product,
                        charge, and multiplicity options for AutoTS are
                        handled by this script. Note this is just for AutoTS
                        keywords not for the Jaguar keywords used bythat
                        workflow which are instead specified using flag
                        -autots_jag_keywords. (default: None)
  -autots_jag_keywords KEYWORD=VALUE KEYWORD=VALUE ...
                        If performing a transition state search for an ERN
                        simulation using -ts_search then specify Jaguar
                        section keywords using this flag. If not specified,
                        then Jaguar keywords used for energy refinement using
                        -keywords will be used. (default: None)
  -taper KCAL/MOL       Skip any product whose relaxed xTB Free energy
                        relative to the reactant exceeds the specified cutoff.
                        Use a cutoff of none to include and report all
                        products regardless of their relative free energy.
                        (default: 40)
  -reps REPLICATES      Number of replicate MD workflows to run (default: 8)
  -refine               Refine product energy using DFT (default: False)
  -refined_taper KCAL/MOL
                        Skip any product whose refined Free energy relative to
                        the reactant exceeds the specified cutoff. Use a
                        cutoff of none to include and report all products
                        regardless of their relative free energy. (default:
                        30)
  -keywords KEYWORD=VALUE KEYWORD=VALUE ...
                        Jaguar keywords given as a space-separated
                        keyword=value pairs. Any keywords given here replace
                        all the default keyword values. (default:
                        basis=LACVP** dftname=M06-L maxit=300 nofail=1)

Job Control Options:
  -HOST <hostname>      Run job remotely on the indicated host entry.
                        (default: localhost)
  -D, -DEBUG            Show details of Job Control operation. (default:
                        False)
  -JOBNAME JOBNAME      Provide an explicit name for the job. (default: None)